@@ -50,11 +50,20 @@ class FileStore(TokenStore):
                         if len(next_record) == 0:
                             continue
                         if self.check_token_exists(user.get_email(), token, next_record):
-                            token.set_id(next_record[0])
-                            token.set_access_token(next_record[5])
-                            token.set_expires_in(next_record[7])
-                            token.set_refresh_token(next_record[4])
-                            return token
+                            grant_token = next_record[6] if next_record[6] is not None and len(
+                                next_record[6]) > 0 else None
+                            redirect_url = next_record[8] if next_record[8] is not None and len(
+                                next_record[8]) > 0 else None
+
+                            oauthtoken = OAuthToken(client_id=next_record[2], client_secret=next_record[3],
+                                                     grant_token=grant_token,
+                                                     redirect_url=redirect_url, refresh_token=next_record[4])
+                            oauthtoken.set_id(next_record[0])
+                            oauthtoken.set_user_mail(next_record[1])
+                            oauthtoken.set_expires_in(next_record[7])
+                            oauthtoken.set_access_token(next_record[5])
+
+                            return oauthtoken
 
         except IOError as ex:
             raise SDKException(code=Constants.TOKEN_STORE, message=Constants.GET_TOKEN_FILE_ERROR, cause=ex)
@@ -105,11 +114,13 @@ class FileStore(TokenStore):
                 for next_record in data:
                     if len(next_record) == 0:
                         continue
-                    grant_token = None
-                    if next_record[6] is not None and len(next_record[6]) > 0:
-                        grant_token = next_record[6]
+                    grant_token = next_record[6] if next_record[6] is not None and len(
+                        next_record[6]) > 0 else None
 
-                    token = OAuthToken(client_id=next_record[2], client_secret=None, grant_token=grant_token, redirect_url=next_record[8], refresh_token=next_record[4])
+                    redirect_url = next_record[8] if next_record[8] is not None and len(
+                        next_record[8]) > 0 else None
+
+                    token = OAuthToken(client_id=next_record[2], client_secret=next_record[3], grant_token=grant_token, redirect_url=redirect_url, refresh_token=next_record[4])
                     token.set_id(next_record[0])
                     token.set_user_mail(next_record[1])
                     token.set_expires_in(next_record[7])
@@ -146,14 +157,14 @@ class FileStore(TokenStore):
                             redirect_url = next_record[8] if next_record[8] is not None and len(
                                 next_record[8]) > 0 else None
 
-                            token = OAuthToken(client_id=next_record[2], client_secret=next_record[3], grant_token=grant_token,
-                                               redirect_url=redirect_url,refresh_token=next_record[4])
-                            token.set_id(next_record[0])
-                            token.set_user_mail(next_record[1])
-                            token.set_expires_in(next_record[7])
-                            token.set_access_token(next_record[5])
+                            oauthtoken = OAuthToken(client_id=next_record[2], client_secret=next_record[3], grant_token=grant_token,
+                                               redirect_url=redirect_url, refresh_token=next_record[4])
+                            oauthtoken.set_id(next_record[0])
+                            oauthtoken.set_user_mail(next_record[1])
+                            oauthtoken.set_expires_in(next_record[7])
+                            oauthtoken.set_access_token(next_record[5])
 
-                            return token
+                            return oauthtoken
                     if not is_row_present:
                         raise SDKException(code=Constants.TOKEN_STORE, message=Constants.GET_TOKEN_BY_ID_FILE_ERROR)
 
@@ -174,5 +185,5 @@ class FileStore(TokenStore):
 
         if row[1] == email and row[2] == client_id and token_check:
             return True
-        
+
         return False
