@@ -20,7 +20,7 @@ class AutoNumber(object):
 		The method to get the prefix
 
 		Returns:
-			string: A string value
+			string: A string representing the prefix
 		"""
 
 		return self.__prefix
@@ -44,7 +44,7 @@ class AutoNumber(object):
 		The method to get the suffix
 
 		Returns:
-			string: A string value
+			string: A string representing the suffix
 		"""
 
 		return self.__suffix
@@ -68,7 +68,7 @@ class AutoNumber(object):
 		The method to get the start_number
 
 		Returns:
-			int: A int value
+			int: An int representing the start_number
 		"""
 
 		return self.__start_number
@@ -95,7 +95,7 @@ class AutoNumber(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
