@@ -34,7 +34,7 @@ class ModulesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/modules'
+		api_path = api_path + '/crm/v2.1/settings/modules'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
@@ -64,7 +64,7 @@ class ModulesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/modules/'
+		api_path = api_path + '/crm/v2.1/settings/modules/'
 		api_path = api_path + str(api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
@@ -103,7 +103,7 @@ class ModulesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/modules/'
+		api_path = api_path + '/crm/v2.1/settings/modules/'
 		api_path = api_path + str(api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
@@ -144,7 +144,7 @@ class ModulesOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/settings/modules/'
+		api_path = api_path + '/crm/v2.1/settings/modules/'
 		api_path = api_path + str(id)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
