@@ -10,62 +10,32 @@ class TransferAndDeleteWrapper(object):
 	def __init__(self):
 		"""Creates an instance of TransferAndDeleteWrapper"""
 
-		self.__pipeline = None
-		self.__stages = None
+		self.__transfer_pipeline = None
 		self.__key_modified = dict()
 
-	def get_pipeline(self):
+	def get_transfer_pipeline(self):
 		"""
-		The method to get the pipeline
-
-		Returns:
-			Pipeline: An instance of Pipeline
-		"""
-
-		return self.__pipeline
-
-	def set_pipeline(self, pipeline):
-		"""
-		The method to set the value to pipeline
-
-		Parameters:
-			pipeline (Pipeline) : An instance of Pipeline
-		"""
-
-		try:
-			from zcrmsdk.src.com.zoho.crm.api.pipeline.pipeline import Pipeline
-		except Exception:
-			from .pipeline import Pipeline
-
-		if pipeline is not None and not isinstance(pipeline, Pipeline):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: pipeline EXPECTED TYPE: Pipeline', None, None)
-		
-		self.__pipeline = pipeline
-		self.__key_modified['pipeline'] = 1
-
-	def get_stages(self):
-		"""
-		The method to get the stages
+		The method to get the transfer_pipeline
 
 		Returns:
 			list: An instance of list
 		"""
 
-		return self.__stages
+		return self.__transfer_pipeline
 
-	def set_stages(self, stages):
+	def set_transfer_pipeline(self, transfer_pipeline):
 		"""
-		The method to set the value to stages
+		The method to set the value to transfer_pipeline
 
 		Parameters:
-			stages (list) : An instance of list
+			transfer_pipeline (list) : An instance of list
 		"""
 
-		if stages is not None and not isinstance(stages, list):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: stages EXPECTED TYPE: list', None, None)
+		if transfer_pipeline is not None and not isinstance(transfer_pipeline, list):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: transfer_pipeline EXPECTED TYPE: list', None, None)
 		
-		self.__stages = stages
-		self.__key_modified['stages'] = 1
+		self.__transfer_pipeline = transfer_pipeline
+		self.__key_modified['transfer_pipeline'] = 1
 
 	def is_key_modified(self, key):
 		"""
