@@ -52,7 +52,7 @@ class DeletedRecord(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -76,7 +76,7 @@ class DeletedRecord(object):
 		The method to get the display_name
 
 		Returns:
-			string: A string value
+			string: A string representing the display_name
 		"""
 
 		return self.__display_name
@@ -100,7 +100,7 @@ class DeletedRecord(object):
 		The method to get the type
 
 		Returns:
-			string: A string value
+			string: A string representing the type
 		"""
 
 		return self.__type
@@ -182,7 +182,7 @@ class DeletedRecord(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
