@@ -32,7 +32,11 @@ class HeaderParamValidator(object):
             type_detail = self.get_key_json_details(name, json_details[json_class_name])
 
         if type_detail is not None:
-            if not self.check_data_type(type_detail, value):
+            try:
+                from zcrmsdk.src.com.zoho.crm.api.util.utility import Utility
+            except Exception:
+                from ..util.utility import Utility
+            if not Utility.check_data_type(type_detail[Constants.TYPE], value):
                 param_or_header = 'PARAMETER' if json_class_name is not None and json_class_name.endswith('Param') else 'HEADER'
                 error_details = {
                     param_or_header: name,
@@ -45,18 +49,7 @@ class HeaderParamValidator(object):
 
         return value
 
-    @staticmethod
-    def check_data_type(key_detail, value):
-        data_type = key_detail[Constants.TYPE]
-
-        if data_type in Constants.DATA_TYPE:
-            if not isinstance(value, Constants.DATA_TYPE.get(data_type)):
-                return False
-
-        return True
-
-    @staticmethod
-    def get_key_json_details(name, json_details):
+    def get_key_json_details(self, name, json_details):
         for key_name in json_details.keys():
             detail = json_details[key_name]
 
@@ -64,8 +57,7 @@ class HeaderParamValidator(object):
                 if detail[Constants.NAME].lower() == name.lower():
                     return detail
 
-    @staticmethod
-    def get_file_name(name):
+    def get_file_name(self, name):
         sdk_name = 'zcrmsdk.src.'
         name_split = str(name).split('.')
         class_name = name_split.pop()
@@ -83,8 +75,7 @@ class HeaderParamValidator(object):
 
         return sdk_name
 
-    @staticmethod
-    def get_json_details():
+    def get_json_details(self):
         try:
             from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
         except Exception:
