@@ -381,7 +381,6 @@ class JSONConverter(Converter):
 
     def get_wrapped_response(self, response, pack):
         try:
-            print (response.json())
             return self.get_response(response.json(), pack)
 
         except ValueError:
@@ -677,8 +676,7 @@ class JSONConverter(Converter):
 
         return matches / total_points
 
-    @staticmethod
-    def build_name(member_name):
+    def build_name(self, member_name):
         name_split = str(member_name).split('_')
         sdk_name = name_split[0].lower()
 
@@ -698,12 +696,10 @@ class JSONConverter(Converter):
         return class_holder()
 
 
-    @staticmethod
-    def construct_private_member(class_name, member_name):
+    def construct_private_member(self, class_name, member_name):
         return '_' + class_name + '__' + member_name
 
-    @staticmethod
-    def __get_choice_instance(data):
+    def __get_choice_instance(self, data):
         choice_split = Constants.CHOICE_NAMESPACE.rpartition('.')
         imported_module = importlib.import_module(choice_split[0])
         class_holder = getattr(imported_module, choice_split[-1])
